@@ -11,20 +11,28 @@
 # Module Name:  __init__.py
 # Description:
 # ****************************************************************
-from .client import Client
-from .discount import Discount
-from .document_type import DocumentType
-from .geographic_location import GeographicLocation
+from .local_company import Company
+from .local_document_type import DocumentType
+from .local_product import Product
+from .oasis_client import OasisClient
+from .oasis_company import OasisCompany
+from .oasis_cycle import Cycle
+from .oasis_discount import OasisDiscount
+from .oasis_geographic_location import OasisGeographicLocation
+from .oasis_periods import Periods
 from .oasis_product import OasisProduct
-from .product import Product
-from .type_client import TypeClient
+from .oasis_type_client import OasisTypeClient
+
 
 __all__ = [
-    "Client",
-    "Discount",
+    "Company",
+    "Cycle",
     "DocumentType",
-    "GeographicLocation",
-    "Product",
+    "OasisClient",
+    "OasisCompany",
+    "OasisDiscount",
+    "OasisGeographicLocation",
     "OasisProduct",
-    "TypeClient"
+    "OasisTypeClient",
+    "Product"
 ]
