@@ -11,23 +11,32 @@
 # Module Name:  __init__.py
 # Description:
 # ****************************************************************
-from .oasis_models import Classification
-from .oasis_models import Client
-from .oasis_models import Discount
-from .oasis_models import GeographicLocation
-from .oasis_models import OasisProduct
-from .oasis_models import TypeClient
+from .local_models import Company
 from .local_models import DocumentType
 from .local_models import Product
+from .oasis_models import Account
+from .oasis_models import Classification
+from .oasis_models import Client
+from .oasis_models import Cycle
+from .oasis_models import Discount
+from .oasis_models import GeographicLocation
+from .oasis_models import OasisCompany
+from .oasis_models import OasisProduct
+from .oasis_models import Periods
+from .oasis_models import TypeClient
 
 __all__ = [
     "Classification",
     "Client",
+    "Company",
+    "Cycle",
     "Discount",
     "DocumentType",
     "GeographicLocation",
     "Product",
+    "OasisCompany",
     "OasisProduct",
+    "Periods",
     "TypeClient"
 ]
 
