@@ -11,10 +11,12 @@
 # Module Name:  __init__.py
 # Description:
 # ****************************************************************
-from oasis.tasks.load_products import load_products
-from oasis.tasks.sync_document_types import sync_document_types
+from .sync_company import sync_company
+from .sync_document_types import sync_document_types
+from .sync_products import sync_products
 
 __all__ = [
-    "load_products",
+    "sync_products",
+    "sync_company",
     "sync_document_types"
 ]
